# Ensemble Clustering

::: flyvis.analysis.clustering.compute_umap_and_clustering

::: flyvis.analysis.clustering.umap_embedding

::: flyvis.analysis.clustering.GaussianMixtureClustering

::: flyvis.analysis.clustering.EnsembleEmbedding

::: flyvis.analysis.clustering.Embedding

::: flyvis.analysis.clustering.Clustering
